==> xmonad-contrib-0.18.1-108-riscv64.pkg.tar.zst: usr/share/haskell/register/xmonad-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-contrib
version:              0.18.1
visibility:           public
id:                   xmonad-contrib-0.18.1-Kkr0ZKcbQyG9co872xw8CW
key:                  xmonad-contrib-0.18.1-Kkr0ZKcbQyG9co872xw8CW
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:               Spencer Janssen & others
homepage:             https://xmonad.org/
synopsis:             Community-maintained extensions for xmonad
description:
    Community-maintained tiling algorithms and extension modules for xmonad,
    an X11 tiling window manager.

    For an introduction to building, configuring and using xmonad
    extensions, see "XMonad.Doc". In particular:

    "XMonad.Doc.Configuring", a guide to configuring xmonad

    "XMonad.Doc.Extending", using the contributed extensions library

    "XMonad.Doc.Developing", introduction to xmonad internals and writing
    your own extensions.

category:             System
abi:                  c3f717721964f97971977bab96ac3367
exposed:              True
exposed-modules:
    XMonad.Actions.AfterDrag XMonad.Actions.BluetileCommands
    XMonad.Actions.Commands XMonad.Actions.ConstrainedResize
    XMonad.Actions.CopyWindow XMonad.Actions.CycleRecentWS
    XMonad.Actions.CycleSelectedLayouts XMonad.Actions.CycleWS
    XMonad.Actions.CycleWindows XMonad.Actions.CycleWorkspaceByScreen
    XMonad.Actions.DeManage XMonad.Actions.DwmPromote
    XMonad.Actions.DynamicProjects
    XMonad.Actions.DynamicWorkspaceGroups
    XMonad.Actions.DynamicWorkspaceOrder
    XMonad.Actions.DynamicWorkspaces XMonad.Actions.EasyMotion
    XMonad.Actions.FindEmptyWorkspace XMonad.Actions.FlexibleManipulate
    XMonad.Actions.FlexibleResize XMonad.Actions.FloatKeys
    XMonad.Actions.FloatSnap XMonad.Actions.FocusNth
    XMonad.Actions.GridSelect XMonad.Actions.GroupNavigation
    XMonad.Actions.KeyRemap XMonad.Actions.Launcher
    XMonad.Actions.LinkWorkspaces XMonad.Actions.MessageFeedback
    XMonad.Actions.Minimize XMonad.Actions.MostRecentlyUsed
    XMonad.Actions.MouseGestures XMonad.Actions.MouseResize
    XMonad.Actions.Navigation2D XMonad.Actions.NoBorders
    XMonad.Actions.OnScreen XMonad.Actions.PerLayoutKeys
    XMonad.Actions.PerWindowKeys XMonad.Actions.PerWorkspaceKeys
    XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
    XMonad.Actions.Prefix XMonad.Actions.Profiles
    XMonad.Actions.Promote XMonad.Actions.RandomBackground
    XMonad.Actions.RepeatAction XMonad.Actions.Repeatable
    XMonad.Actions.RotSlaves XMonad.Actions.RotateSome
    XMonad.Actions.Search XMonad.Actions.ShowText XMonad.Actions.Sift
    XMonad.Actions.SimpleDate XMonad.Actions.SinkAll
    XMonad.Actions.SpawnOn XMonad.Actions.Submap
    XMonad.Actions.SwapPromote XMonad.Actions.SwapWorkspaces
    XMonad.Actions.TagWindows XMonad.Actions.TiledWindowDragging
    XMonad.Actions.ToggleFullFloat XMonad.Actions.TopicSpace
    XMonad.Actions.TreeSelect XMonad.Actions.UpdateFocus
    XMonad.Actions.UpdatePointer XMonad.Actions.Warp
    XMonad.Actions.WindowBringer XMonad.Actions.WindowGo
    XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
    XMonad.Actions.WithAll XMonad.Actions.Workscreen
    XMonad.Actions.WorkspaceCursors XMonad.Actions.WorkspaceNames
    XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Bepo
    XMonad.Config.Bluetile XMonad.Config.Desktop XMonad.Config.Dmwit
    XMonad.Config.Droundy XMonad.Config.Gnome XMonad.Config.Kde
    XMonad.Config.Mate XMonad.Config.Prime XMonad.Config.Sjanssen
    XMonad.Config.Xfce XMonad.Doc XMonad.Doc.Configuring
    XMonad.Doc.Developing XMonad.Doc.Extending
    XMonad.Hooks.BorderPerWindow XMonad.Hooks.CurrentWorkspaceOnTop
    XMonad.Hooks.DebugEvents XMonad.Hooks.DebugKeyEvents
    XMonad.Hooks.DebugStack XMonad.Hooks.DynamicBars
    XMonad.Hooks.DynamicHooks XMonad.Hooks.DynamicIcons
    XMonad.Hooks.DynamicLog XMonad.Hooks.DynamicProperty
    XMonad.Hooks.EwmhDesktops XMonad.Hooks.FadeInactive
    XMonad.Hooks.FadeWindows XMonad.Hooks.FloatConfigureReq
    XMonad.Hooks.FloatNext XMonad.Hooks.Focus
    XMonad.Hooks.InsertPosition XMonad.Hooks.ManageDebug
    XMonad.Hooks.ManageDocks XMonad.Hooks.ManageHelpers
    XMonad.Hooks.Minimize XMonad.Hooks.Modal
    XMonad.Hooks.OnPropertyChange XMonad.Hooks.Place
    XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RefocusLast
    XMonad.Hooks.Rescreen XMonad.Hooks.ScreenCorners
    XMonad.Hooks.Script XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
    XMonad.Hooks.ShowWName XMonad.Hooks.StatusBar
    XMonad.Hooks.StatusBar.PP XMonad.Hooks.StatusBar.WorkspaceScreen
    XMonad.Hooks.TaffybarPagerHints XMonad.Hooks.ToggleHook
    XMonad.Hooks.UrgencyHook XMonad.Hooks.WallpaperSetter
    XMonad.Hooks.WindowSwallowing XMonad.Hooks.WorkspaceByPos
    XMonad.Hooks.WorkspaceHistory XMonad.Hooks.XPropManage
    XMonad.Layout.Accordion XMonad.Layout.AutoMaster
    XMonad.Layout.AvoidFloats XMonad.Layout.BinaryColumn
    XMonad.Layout.BinarySpacePartition XMonad.Layout.BorderResize
    XMonad.Layout.BoringWindows XMonad.Layout.ButtonDecoration
    XMonad.Layout.CenterMainFluid XMonad.Layout.CenteredIfSingle
    XMonad.Layout.CenteredMaster XMonad.Layout.Circle
    XMonad.Layout.CircleEx XMonad.Layout.Column XMonad.Layout.Columns
    XMonad.Layout.Combo XMonad.Layout.ComboP XMonad.Layout.Cross
    XMonad.Layout.Decoration XMonad.Layout.DecorationAddons
    XMonad.Layout.DecorationEx XMonad.Layout.DecorationEx.Common
    XMonad.Layout.DecorationEx.DwmGeometry
    XMonad.Layout.DecorationEx.Engine
    XMonad.Layout.DecorationEx.Geometry
    XMonad.Layout.DecorationEx.LayoutModifier
    XMonad.Layout.DecorationEx.TabbedGeometry
    XMonad.Layout.DecorationEx.TextEngine
    XMonad.Layout.DecorationEx.Widgets XMonad.Layout.DecorationMadness
    XMonad.Layout.Dishes XMonad.Layout.DragPane
    XMonad.Layout.DraggingVisualizer XMonad.Layout.Drawer
    XMonad.Layout.Dwindle XMonad.Layout.DwmStyle
    XMonad.Layout.FixedAspectRatio XMonad.Layout.FixedColumn
    XMonad.Layout.FocusTracking XMonad.Layout.Fullscreen
    XMonad.Layout.Gaps XMonad.Layout.Grid XMonad.Layout.GridVariants
    XMonad.Layout.Groups XMonad.Layout.Groups.Examples
    XMonad.Layout.Groups.Helpers XMonad.Layout.Groups.Wmii
    XMonad.Layout.Hidden XMonad.Layout.HintedGrid
    XMonad.Layout.HintedTile XMonad.Layout.IM XMonad.Layout.IfMax
    XMonad.Layout.ImageButtonDecoration
    XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
    XMonad.Layout.LayoutCombinators XMonad.Layout.LayoutHints
    XMonad.Layout.LayoutModifier XMonad.Layout.LayoutScreens
    XMonad.Layout.LimitWindows XMonad.Layout.MagicFocus
    XMonad.Layout.Magnifier XMonad.Layout.Master XMonad.Layout.Maximize
    XMonad.Layout.MessageControl XMonad.Layout.Minimize
    XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
    XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
    XMonad.Layout.MultiDishes XMonad.Layout.MultiToggle
    XMonad.Layout.MultiToggle.Instances
    XMonad.Layout.MultiToggle.TabBarDecoration XMonad.Layout.Named
    XMonad.Layout.NoBorders XMonad.Layout.NoFrillsDecoration
    XMonad.Layout.OnHost XMonad.Layout.OneBig XMonad.Layout.PerScreen
    XMonad.Layout.PerWorkspace XMonad.Layout.PositionStoreFloat
    XMonad.Layout.Reflect XMonad.Layout.Renamed
    XMonad.Layout.ResizableThreeColumns XMonad.Layout.ResizableTile
    XMonad.Layout.ResizeScreen XMonad.Layout.Roledex
    XMonad.Layout.ShowWName XMonad.Layout.SideBorderDecoration
    XMonad.Layout.SimpleDecoration XMonad.Layout.SimpleFloat
    XMonad.Layout.Simplest XMonad.Layout.SimplestFloat
    XMonad.Layout.SortedLayout XMonad.Layout.Spacing
    XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.StackTile
    XMonad.Layout.StateFull XMonad.Layout.Stoppable
    XMonad.Layout.SubLayouts XMonad.Layout.TabBarDecoration
    XMonad.Layout.Tabbed XMonad.Layout.TallMastersCombo
    XMonad.Layout.ThreeColumns XMonad.Layout.ToggleLayouts
    XMonad.Layout.TrackFloating XMonad.Layout.TwoPane
    XMonad.Layout.TwoPanePersistent XMonad.Layout.VoidBorders
    XMonad.Layout.WindowArranger XMonad.Layout.WindowNavigation
    XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
    XMonad.Layout.ZoomRow XMonad.Prelude XMonad.Prompt
    XMonad.Prompt.AppLauncher XMonad.Prompt.AppendFile
    XMonad.Prompt.ConfirmPrompt XMonad.Prompt.DirExec
    XMonad.Prompt.Directory XMonad.Prompt.Email
    XMonad.Prompt.FuzzyMatch XMonad.Prompt.Input XMonad.Prompt.Layout
    XMonad.Prompt.Man XMonad.Prompt.OrgMode XMonad.Prompt.Pass
    XMonad.Prompt.RunOrRaise XMonad.Prompt.Shell XMonad.Prompt.Ssh
    XMonad.Prompt.Theme XMonad.Prompt.Unicode XMonad.Prompt.Window
    XMonad.Prompt.Workspace XMonad.Prompt.XMonad XMonad.Prompt.Zsh
    XMonad.Util.ActionCycle XMonad.Util.ActionQueue
    XMonad.Util.ClickableWorkspaces XMonad.Util.Cursor
    XMonad.Util.CustomKeys XMonad.Util.DebugWindow XMonad.Util.Dmenu
    XMonad.Util.DynamicScratchpads XMonad.Util.Dzen
    XMonad.Util.EZConfig XMonad.Util.ExclusiveScratchpads
    XMonad.Util.ExtensibleConf XMonad.Util.ExtensibleState
    XMonad.Util.Font XMonad.Util.Grab XMonad.Util.Hacks
    XMonad.Util.History XMonad.Util.Image XMonad.Util.Invisible
    XMonad.Util.Loggers XMonad.Util.Loggers.NamedScratchpad
    XMonad.Util.Minimize XMonad.Util.NamedActions
    XMonad.Util.NamedScratchpad XMonad.Util.NamedWindows
    XMonad.Util.NoTaskbar XMonad.Util.Parser XMonad.Util.Paste
    XMonad.Util.PositionStore XMonad.Util.Process XMonad.Util.PureX
    XMonad.Util.Rectangle XMonad.Util.RemoteWindows XMonad.Util.Replace
    XMonad.Util.Run XMonad.Util.Scratchpad XMonad.Util.SessionStart
    XMonad.Util.SpawnNamedPipe XMonad.Util.SpawnOnce XMonad.Util.Stack
    XMonad.Util.StringProp XMonad.Util.Themes XMonad.Util.Timer
    XMonad.Util.TreeZipper XMonad.Util.Types XMonad.Util.Ungrab
    XMonad.Util.WindowProperties XMonad.Util.WindowState
    XMonad.Util.WorkspaceCompare XMonad.Util.XSelection
    XMonad.Util.XUtils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-contrib-0.18.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-contrib-0.18.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-contrib-0.18.1
dynamic-library-dirs: /usr/lib/riscv64-linux-ghc-9.4.8
data-dir:             /usr/share/xmonad-contrib
hs-libraries:         HSxmonad-contrib-0.18.1-Kkr0ZKcbQyG9co872xw8CW
depends:
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    X11-xft-0.3.4-61aeKG67bqvE82547QENGs base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2 process-1.6.18.0
    random-1.2.1.3-KpmZVmsijPULH6l5PrmXSD time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xmonad-0.18.0-GLF9DtFf0xA137oEkCMUf9

haddock-interfaces:   /usr/share/doc/xmonad-contrib/html/xmonad-contrib.haddock
haddock-html:         /usr/share/doc/xmonad-contrib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-contrib-0.18.1-127-riscv64.pkg.tar.zst: usr/share/haskell/register/xmonad-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-contrib
version:              0.18.1
visibility:           public
id:                   xmonad-contrib-0.18.1-Ht9lqBJN05JHbPwtvwVWua
key:                  xmonad-contrib-0.18.1-Ht9lqBJN05JHbPwtvwVWua
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:               Spencer Janssen & others
homepage:             https://xmonad.org/
synopsis:             Community-maintained extensions for xmonad
description:
    Community-maintained tiling algorithms and extension modules for xmonad,
    an X11 tiling window manager.

    For an introduction to building, configuring and using xmonad
    extensions, see "XMonad.Doc". In particular:

    "XMonad.Doc.Configuring", a guide to configuring xmonad

    "XMonad.Doc.Extending", using the contributed extensions library

    "XMonad.Doc.Developing", introduction to xmonad internals and writing
    your own extensions.

category:             System
abi:                  7c0bd3c41fc95c5e31f05b4a3d6c6aac
exposed:              True
exposed-modules:
    XMonad.Actions.AfterDrag XMonad.Actions.BluetileCommands
    XMonad.Actions.Commands XMonad.Actions.ConstrainedResize
    XMonad.Actions.CopyWindow XMonad.Actions.CycleRecentWS
    XMonad.Actions.CycleSelectedLayouts XMonad.Actions.CycleWS
    XMonad.Actions.CycleWindows XMonad.Actions.CycleWorkspaceByScreen
    XMonad.Actions.DeManage XMonad.Actions.DwmPromote
    XMonad.Actions.DynamicProjects
    XMonad.Actions.DynamicWorkspaceGroups
    XMonad.Actions.DynamicWorkspaceOrder
    XMonad.Actions.DynamicWorkspaces XMonad.Actions.EasyMotion
    XMonad.Actions.FindEmptyWorkspace XMonad.Actions.FlexibleManipulate
    XMonad.Actions.FlexibleResize XMonad.Actions.FloatKeys
    XMonad.Actions.FloatSnap XMonad.Actions.FocusNth
    XMonad.Actions.GridSelect XMonad.Actions.GroupNavigation
    XMonad.Actions.KeyRemap XMonad.Actions.Launcher
    XMonad.Actions.LinkWorkspaces XMonad.Actions.MessageFeedback
    XMonad.Actions.Minimize XMonad.Actions.MostRecentlyUsed
    XMonad.Actions.MouseGestures XMonad.Actions.MouseResize
    XMonad.Actions.Navigation2D XMonad.Actions.NoBorders
    XMonad.Actions.OnScreen XMonad.Actions.PerLayoutKeys
    XMonad.Actions.PerWindowKeys XMonad.Actions.PerWorkspaceKeys
    XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
    XMonad.Actions.Prefix XMonad.Actions.Profiles
    XMonad.Actions.Promote XMonad.Actions.RandomBackground
    XMonad.Actions.RepeatAction XMonad.Actions.Repeatable
    XMonad.Actions.RotSlaves XMonad.Actions.RotateSome
    XMonad.Actions.Search XMonad.Actions.ShowText XMonad.Actions.Sift
    XMonad.Actions.SimpleDate XMonad.Actions.SinkAll
    XMonad.Actions.SpawnOn XMonad.Actions.Submap
    XMonad.Actions.SwapPromote XMonad.Actions.SwapWorkspaces
    XMonad.Actions.TagWindows XMonad.Actions.TiledWindowDragging
    XMonad.Actions.ToggleFullFloat XMonad.Actions.TopicSpace
    XMonad.Actions.TreeSelect XMonad.Actions.UpdateFocus
    XMonad.Actions.UpdatePointer XMonad.Actions.Warp
    XMonad.Actions.WindowBringer XMonad.Actions.WindowGo
    XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
    XMonad.Actions.WithAll XMonad.Actions.Workscreen
    XMonad.Actions.WorkspaceCursors XMonad.Actions.WorkspaceNames
    XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Bepo
    XMonad.Config.Bluetile XMonad.Config.Desktop XMonad.Config.Dmwit
    XMonad.Config.Droundy XMonad.Config.Gnome XMonad.Config.Kde
    XMonad.Config.Mate XMonad.Config.Prime XMonad.Config.Sjanssen
    XMonad.Config.Xfce XMonad.Doc XMonad.Doc.Configuring
    XMonad.Doc.Developing XMonad.Doc.Extending
    XMonad.Hooks.BorderPerWindow XMonad.Hooks.CurrentWorkspaceOnTop
    XMonad.Hooks.DebugEvents XMonad.Hooks.DebugKeyEvents
    XMonad.Hooks.DebugStack XMonad.Hooks.DynamicBars
    XMonad.Hooks.DynamicHooks XMonad.Hooks.DynamicIcons
    XMonad.Hooks.DynamicLog XMonad.Hooks.DynamicProperty
    XMonad.Hooks.EwmhDesktops XMonad.Hooks.FadeInactive
    XMonad.Hooks.FadeWindows XMonad.Hooks.FloatConfigureReq
    XMonad.Hooks.FloatNext XMonad.Hooks.Focus
    XMonad.Hooks.InsertPosition XMonad.Hooks.ManageDebug
    XMonad.Hooks.ManageDocks XMonad.Hooks.ManageHelpers
    XMonad.Hooks.Minimize XMonad.Hooks.Modal
    XMonad.Hooks.OnPropertyChange XMonad.Hooks.Place
    XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RefocusLast
    XMonad.Hooks.Rescreen XMonad.Hooks.ScreenCorners
    XMonad.Hooks.Script XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
    XMonad.Hooks.ShowWName XMonad.Hooks.StatusBar
    XMonad.Hooks.StatusBar.PP XMonad.Hooks.StatusBar.WorkspaceScreen
    XMonad.Hooks.TaffybarPagerHints XMonad.Hooks.ToggleHook
    XMonad.Hooks.UrgencyHook XMonad.Hooks.WallpaperSetter
    XMonad.Hooks.WindowSwallowing XMonad.Hooks.WorkspaceByPos
    XMonad.Hooks.WorkspaceHistory XMonad.Hooks.XPropManage
    XMonad.Layout.Accordion XMonad.Layout.AutoMaster
    XMonad.Layout.AvoidFloats XMonad.Layout.BinaryColumn
    XMonad.Layout.BinarySpacePartition XMonad.Layout.BorderResize
    XMonad.Layout.BoringWindows XMonad.Layout.ButtonDecoration
    XMonad.Layout.CenterMainFluid XMonad.Layout.CenteredIfSingle
    XMonad.Layout.CenteredMaster XMonad.Layout.Circle
    XMonad.Layout.CircleEx XMonad.Layout.Column XMonad.Layout.Columns
    XMonad.Layout.Combo XMonad.Layout.ComboP XMonad.Layout.Cross
    XMonad.Layout.Decoration XMonad.Layout.DecorationAddons
    XMonad.Layout.DecorationEx XMonad.Layout.DecorationEx.Common
    XMonad.Layout.DecorationEx.DwmGeometry
    XMonad.Layout.DecorationEx.Engine
    XMonad.Layout.DecorationEx.Geometry
    XMonad.Layout.DecorationEx.LayoutModifier
    XMonad.Layout.DecorationEx.TabbedGeometry
    XMonad.Layout.DecorationEx.TextEngine
    XMonad.Layout.DecorationEx.Widgets XMonad.Layout.DecorationMadness
    XMonad.Layout.Dishes XMonad.Layout.DragPane
    XMonad.Layout.DraggingVisualizer XMonad.Layout.Drawer
    XMonad.Layout.Dwindle XMonad.Layout.DwmStyle
    XMonad.Layout.FixedAspectRatio XMonad.Layout.FixedColumn
    XMonad.Layout.FocusTracking XMonad.Layout.Fullscreen
    XMonad.Layout.Gaps XMonad.Layout.Grid XMonad.Layout.GridVariants
    XMonad.Layout.Groups XMonad.Layout.Groups.Examples
    XMonad.Layout.Groups.Helpers XMonad.Layout.Groups.Wmii
    XMonad.Layout.Hidden XMonad.Layout.HintedGrid
    XMonad.Layout.HintedTile XMonad.Layout.IM XMonad.Layout.IfMax
    XMonad.Layout.ImageButtonDecoration
    XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
    XMonad.Layout.LayoutCombinators XMonad.Layout.LayoutHints
    XMonad.Layout.LayoutModifier XMonad.Layout.LayoutScreens
    XMonad.Layout.LimitWindows XMonad.Layout.MagicFocus
    XMonad.Layout.Magnifier XMonad.Layout.Master XMonad.Layout.Maximize
    XMonad.Layout.MessageControl XMonad.Layout.Minimize
    XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
    XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
    XMonad.Layout.MultiDishes XMonad.Layout.MultiToggle
    XMonad.Layout.MultiToggle.Instances
    XMonad.Layout.MultiToggle.TabBarDecoration XMonad.Layout.Named
    XMonad.Layout.NoBorders XMonad.Layout.NoFrillsDecoration
    XMonad.Layout.OnHost XMonad.Layout.OneBig XMonad.Layout.PerScreen
    XMonad.Layout.PerWorkspace XMonad.Layout.PositionStoreFloat
    XMonad.Layout.Reflect XMonad.Layout.Renamed
    XMonad.Layout.ResizableThreeColumns XMonad.Layout.ResizableTile
    XMonad.Layout.ResizeScreen XMonad.Layout.Roledex
    XMonad.Layout.ShowWName XMonad.Layout.SideBorderDecoration
    XMonad.Layout.SimpleDecoration XMonad.Layout.SimpleFloat
    XMonad.Layout.Simplest XMonad.Layout.SimplestFloat
    XMonad.Layout.SortedLayout XMonad.Layout.Spacing
    XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.StackTile
    XMonad.Layout.StateFull XMonad.Layout.Stoppable
    XMonad.Layout.SubLayouts XMonad.Layout.TabBarDecoration
    XMonad.Layout.Tabbed XMonad.Layout.TallMastersCombo
    XMonad.Layout.ThreeColumns XMonad.Layout.ToggleLayouts
    XMonad.Layout.TrackFloating XMonad.Layout.TwoPane
    XMonad.Layout.TwoPanePersistent XMonad.Layout.VoidBorders
    XMonad.Layout.WindowArranger XMonad.Layout.WindowNavigation
    XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
    XMonad.Layout.ZoomRow XMonad.Prelude XMonad.Prompt
    XMonad.Prompt.AppLauncher XMonad.Prompt.AppendFile
    XMonad.Prompt.ConfirmPrompt XMonad.Prompt.DirExec
    XMonad.Prompt.Directory XMonad.Prompt.Email
    XMonad.Prompt.FuzzyMatch XMonad.Prompt.Input XMonad.Prompt.Layout
    XMonad.Prompt.Man XMonad.Prompt.OrgMode XMonad.Prompt.Pass
    XMonad.Prompt.RunOrRaise XMonad.Prompt.Shell XMonad.Prompt.Ssh
    XMonad.Prompt.Theme XMonad.Prompt.Unicode XMonad.Prompt.Window
    XMonad.Prompt.Workspace XMonad.Prompt.XMonad XMonad.Prompt.Zsh
    XMonad.Util.ActionCycle XMonad.Util.ActionQueue
    XMonad.Util.ClickableWorkspaces XMonad.Util.Cursor
    XMonad.Util.CustomKeys XMonad.Util.DebugWindow XMonad.Util.Dmenu
    XMonad.Util.DynamicScratchpads XMonad.Util.Dzen
    XMonad.Util.EZConfig XMonad.Util.ExclusiveScratchpads
    XMonad.Util.ExtensibleConf XMonad.Util.ExtensibleState
    XMonad.Util.Font XMonad.Util.Grab XMonad.Util.Hacks
    XMonad.Util.History XMonad.Util.Image XMonad.Util.Invisible
    XMonad.Util.Loggers XMonad.Util.Loggers.NamedScratchpad
    XMonad.Util.Minimize XMonad.Util.NamedActions
    XMonad.Util.NamedScratchpad XMonad.Util.NamedWindows
    XMonad.Util.NoTaskbar XMonad.Util.Parser XMonad.Util.Paste
    XMonad.Util.PositionStore XMonad.Util.Process XMonad.Util.PureX
    XMonad.Util.Rectangle XMonad.Util.RemoteWindows XMonad.Util.Replace
    XMonad.Util.Run XMonad.Util.Scratchpad XMonad.Util.SessionStart
    XMonad.Util.SpawnNamedPipe XMonad.Util.SpawnOnce XMonad.Util.Stack
    XMonad.Util.StringProp XMonad.Util.Themes XMonad.Util.Timer
    XMonad.Util.TreeZipper XMonad.Util.Types XMonad.Util.Ungrab
    XMonad.Util.WindowProperties XMonad.Util.WindowState
    XMonad.Util.WorkspaceCompare XMonad.Util.XSelection
    XMonad.Util.XUtils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-contrib-0.18.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-contrib-0.18.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-contrib-0.18.1
dynamic-library-dirs: /usr/lib/riscv64-linux-ghc-9.4.8
data-dir:             /usr/share/xmonad-contrib
hs-libraries:         HSxmonad-contrib-0.18.1-Ht9lqBJN05JHbPwtvwVWua
depends:
    X11-1.10.3-296FmCDygJo4Xo4fAuEwJZ
    X11-xft-0.3.4-KDDg7VHuM1h3G3OtpeQ0sv base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2 process-1.6.18.0
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    xmonad-0.18.0-CW2ThBsG6u778TpJuGrtuP

haddock-interfaces:   /usr/share/doc/xmonad-contrib/html/xmonad-contrib.haddock
haddock-html:         /usr/share/doc/xmonad-contrib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
